@@ -30,7 +30,6 @@
 #include "dialog.h"
 #include "draw.h"
 #include "events.h"
-#include "splash.h"
 
 #include "game.h"
 #include "hand.h"
@@ -39,7 +38,7 @@
 using namespace std;
 
 static GtkWidget *hint_dlg = NULL;
-static GtkObject* deck_edit = NULL;
+static GtkWidget * deck_edit = NULL;
 
 gboolean
 get_insurance_choice ()
@@ -54,8 +53,12 @@ get_insurance_choice ()
                                    GTK_DIALOG_MODAL,
                                    GTK_MESSAGE_QUESTION,
                                    GTK_BUTTONS_YES_NO,
+                                   "<span weight=\"bold\" size=\"larger\">%s</span>",
                                    message);
+  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
+  gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label),
+                            TRUE);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
 
   /* add a stock icon? */ 
@@ -75,25 +78,6 @@ get_insurance_choice ()
   return choice;
 }
 
-void
-select_rule_cb (GtkTreeSelection *select, gpointer data)
-{
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-  gchar *filename = NULL;
-
-	if (gtk_tree_selection_get_selected (select, &model, &iter))
-    {
-      gtk_tree_model_get (model, &iter, 1, &filename, -1);
-      if (g_ascii_strcasecmp (filename, bj_game_get_rules_file ()))
-        {
-          splash_new ();
-          bj_game_new (filename, &seed);
-          splash_destroy ();
-        }
-    }
-}
-
 static void
 hint_destroy_callback (void)
 {
@@ -122,8 +106,11 @@ show_hint_dialog ()
 	                                   GTK_DIALOG_DESTROY_WITH_PARENT,
 	                                   GTK_MESSAGE_INFO,
 	                                   GTK_BUTTONS_OK,
+                                     "<span weight=\"bold\" size=\"larger\">%s</span>",
 	                                   gmessage);
 
+  gtk_dialog_set_has_separator (GTK_DIALOG (hint_dlg), FALSE);
+  gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (hint_dlg)->label), TRUE);
   if (hint_dlg)
     {
       g_signal_connect (G_OBJECT (hint_dlg),
@@ -138,38 +125,12 @@ show_hint_dialog ()
   g_free (gmessage);
 }
 
-GtkWidget *
-get_main_page (GtkWidget* dialog)
-{
-  GtkWidget *retval = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
-
-  gtk_widget_show_all (retval);
-  return retval;
-}
-
-GtkWidget *
-get_background_page (GtkWidget* dialog)
-{
-  GtkWidget *retval = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
-
-  gtk_widget_show_all (retval);
-  return retval;
-}
-
 void 
 pref_dialog_response (GtkWidget *w, int response, gpointer data)
 {
   GdkCardDeckOptions deck_options = NULL;
 
   gtk_widget_hide (w);
-
-  if (gdk_card_deck_options_edit_dirty
-      (GDK_CARD_DECK_OPTIONS_EDIT (deck_edit)))
-    {
-      deck_options =
-        gdk_card_deck_options_edit_get (GDK_CARD_DECK_OPTIONS_EDIT (deck_edit));
-      bj_set_deck_options (deck_options);
-    }
 }
 
 void
@@ -177,14 +138,11 @@ card_deck_options_changed (GtkWidget *w, gpointer data)
 {
   GdkCardDeckOptions deck_options = NULL;
 
-  if (GDK_IS_CARD_DECK_OPTIONS_EDIT (deck_edit)) 
+  if (GTK_IS_CARD_DECK_OPTIONS_EDIT (deck_edit)) 
     {
-#if 0
-      // FIXME: why doesn't this work???
-      deck_options = gdk_card_deck_options_edit_get
-        (GDK_CARD_DECK_OPTIONS_EDIT (deck_edit));
+      deck_options = gtk_card_deck_options_edit_get
+        (GTK_CARD_DECK_OPTIONS_EDIT (deck_edit));
       bj_set_deck_options (deck_options);
-#endif
     }
 }
 
@@ -202,6 +160,43 @@ quick_deal_toggle_cb (GtkToggleButton *w, gpointer data)
   bj_set_quick_deal (is_on);
 }
 
+enum {
+  NAME_STRING,
+  NDECKS_STRING,
+  HIT_SOFT17_STRING,
+  DOUBLE_ANY_STRING,
+  DOUBLE_9_STRING,
+  DOUBLE_SOFT_STRING,
+  DOUBLE_AFTER_HIT_STRING,
+  DOUBLE_AFTER_SPLIT_STRING,
+  RESPLIT_STRING,
+  RESPLIT_ACES_STRING,
+  SURRENDER_STRING,
+  DEALER_SPEED_STRING,
+  FILENAME_STRING
+}; /* Column indices for list */
+
+void
+select_rule_cb (GtkTreeSelection *select, gpointer data)
+{
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+  gchar *filename = NULL;
+
+	if (gtk_tree_selection_get_selected (select, &model, &iter))
+    {
+      gtk_tree_model_get (model, &iter, FILENAME_STRING, &filename, -1);
+      if (g_ascii_strcasecmp (filename, bj_game_get_rules_file ()))
+        {
+          if (data != NULL)
+            gtk_widget_set_sensitive (GTK_WIDGET (data), FALSE);
+          bj_game_new (filename, &seed);
+          if (data != NULL)
+            gtk_widget_set_sensitive (GTK_WIDGET (data), TRUE);
+        }
+    }
+}
+
 void
 show_preferences_dialog () 
 {
@@ -228,15 +223,17 @@ show_preferences_dialog ()
                                                  GTK_STOCK_CLOSE, 
                                                  GTK_RESPONSE_CLOSE,
                                                  NULL);
+      gtk_dialog_set_has_separator (GTK_DIALOG (pref_dialog), FALSE);
       notebook = gtk_notebook_new ();
       gtk_container_add (GTK_CONTAINER (GTK_DIALOG (pref_dialog)->vbox),
                          notebook);
 
       // Game Tab
       hbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+			gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
       gtk_notebook_append_page ( GTK_NOTEBOOK (notebook), hbox, 
-                                 gtk_label_new (_("Game")) );
-      vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+                                 gtk_label_new_with_mnemonic (_("_Game")) );
+      vbox = gtk_vbox_new (FALSE, 6);
       gtk_box_pack_start_defaults(GTK_BOX (hbox), vbox);
 
       // Show probabilities
@@ -265,19 +262,86 @@ show_preferences_dialog ()
       // Rules Tab
       hbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
       gtk_notebook_append_page ( GTK_NOTEBOOK (notebook), hbox, 
-                                 gtk_label_new (_("Rules")) );
+                                 gtk_label_new_with_mnemonic (_("_Rules")) );
       vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
       gtk_box_pack_start_defaults(GTK_BOX (hbox), vbox);
 
-      list = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+      list = gtk_list_store_new (13, 
+                                 G_TYPE_STRING,  // Name
+                                 G_TYPE_INT,     // Decks
+                                 G_TYPE_BOOLEAN, // Hit Soft 17
+                                 G_TYPE_BOOLEAN, // Double Any Total
+                                 G_TYPE_BOOLEAN, // Double 9
+                                 G_TYPE_BOOLEAN, // Double soft
+                                 G_TYPE_BOOLEAN, // Double after hit
+                                 G_TYPE_BOOLEAN, // Double after split
+                                 G_TYPE_BOOLEAN, // Resplit
+                                 G_TYPE_BOOLEAN, // Resplit aces
+                                 G_TYPE_BOOLEAN, // Surrender
+                                 G_TYPE_INT,     // Dealer speed
+                                 G_TYPE_STRING); // Filename
       list_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
-      gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (list_view), FALSE);
+      gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (list_view), TRUE);
       g_object_unref (G_OBJECT (list));
     
       renderer = gtk_cell_renderer_text_new ();
       column = gtk_tree_view_column_new_with_attributes
-        (_("Rules"), renderer, "text", 0, NULL);
+        (_("Name"), renderer, "text", NAME_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Decks"), renderer, "text", NDECKS_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
     
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Hit Soft 17"), renderer, "text", HIT_SOFT17_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Double Any Total"), renderer, "text", DOUBLE_ANY_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Double 9"), renderer, "text", DOUBLE_9_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Double Soft"), renderer, "text", DOUBLE_SOFT_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Double After Hit"), renderer, "text", DOUBLE_AFTER_HIT_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Double After Split"), renderer, "text", DOUBLE_AFTER_SPLIT_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Resplit"), renderer, "text", RESPLIT_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Resplit Aces"), renderer, "text", RESPLIT_ACES_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Surrender"), renderer, "text", SURRENDER_STRING, NULL);
+      gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+
+      renderer = gtk_cell_renderer_text_new ();
+      column = gtk_tree_view_column_new_with_attributes
+        (_("Dealer Speed"), renderer, "text", DEALER_SPEED_STRING, NULL);
       gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
 
       select = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
@@ -290,39 +354,58 @@ show_preferences_dialog ()
       gtk_container_add (GTK_CONTAINER (scrolled_window), list_view);
 
       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-                                      GTK_POLICY_NEVER,
+                                      GTK_POLICY_AUTOMATIC,
                                       GTK_POLICY_AUTOMATIC);
     
       gtk_box_pack_end (GTK_BOX (vbox), scrolled_window, TRUE, TRUE,
                         GNOME_PAD_SMALL );
 
       g_signal_connect (G_OBJECT (select), "changed", 
-                        GTK_SIGNAL_FUNC (select_rule_cb), NULL);
+                        GTK_SIGNAL_FUNC (select_rule_cb), (gpointer) pref_dialog);
 
       gchar *current_rule;
       current_rule = bj_get_game_variation ();
       gint i = 0;
+      BJGameRules *ruleset;
       for (GList *temptr = bj_game_get_rules_list (); temptr; temptr=temptr->next)
         {
           gchar *text;
           gint row;
-          text = bj_game_file_to_name ((gchar*)temptr->data);
-          gtk_list_store_append (GTK_LIST_STORE (list), &iter);
-          gtk_list_store_set (GTK_LIST_STORE (list), 
-                              &iter, 0, text, 1,
-                              (gchar*)temptr->data, -1);
-          if (! g_ascii_strcasecmp (current_rule, (gchar*)temptr->data))
+          ruleset = bj_game_find_and_read_rules ((gchar*)temptr->data);
+          if (ruleset)
             {
-              gtk_tree_view_set_cursor (GTK_TREE_VIEW (list_view),
-                                        gtk_tree_path_new_from_indices (i, -1),
-                                        NULL, FALSE);
+              text = bj_game_file_to_name ((gchar*)temptr->data);
+              gtk_list_store_append (GTK_LIST_STORE (list), &iter);
+              gtk_list_store_set (GTK_LIST_STORE (list), &iter, 
+                                  NAME_STRING, text, 
+                                  NDECKS_STRING, ruleset->getNumDecks (),
+                                  HIT_SOFT17_STRING, ruleset->getHitSoft17 (),
+                                  DOUBLE_ANY_STRING, ruleset->getDoubleAnyTotal (),
+                                  DOUBLE_9_STRING, ruleset->getDouble9 (),
+                                  DOUBLE_SOFT_STRING, ruleset->getDoubleSoft (),
+                                  DOUBLE_AFTER_HIT_STRING, ruleset->getDoubleAfterHit (),
+                                  DOUBLE_AFTER_SPLIT_STRING, ruleset->getDoubleAfterSplit (),
+                                  RESPLIT_STRING, ruleset->getResplit (),
+                                  RESPLIT_ACES_STRING, ruleset->getResplitAces (),
+                                  SURRENDER_STRING, ruleset->getLateSurrender (),
+                                  DEALER_SPEED_STRING, ruleset->getDealerSpeed (),
+                                  FILENAME_STRING, (gchar*)temptr->data, -1);
+              delete ruleset;
+              if (! g_ascii_strcasecmp (current_rule, (gchar*)temptr->data))
+                {
+                  gtk_tree_view_set_cursor (GTK_TREE_VIEW (list_view),
+                                            gtk_tree_path_new_from_indices (i, -1),
+                                            NULL, FALSE);
+                }
+              i++;
             }
-          i++;
         }
-
+      g_free (current_rule);
 
       // Cards Tab
-      deck_edit = gdk_card_deck_options_edit_new (GTK_NOTEBOOK (notebook));
+      deck_edit = gtk_card_deck_options_edit_new ();
+      gtk_notebook_append_page (GTK_NOTEBOOK (notebook), deck_edit,
+                                gtk_label_new_with_mnemonic (_("Card _Deck")));
 
       g_signal_connect (G_OBJECT (deck_edit), "changed",
                         G_CALLBACK (card_deck_options_changed), NULL);
@@ -338,8 +421,9 @@ show_preferences_dialog ()
   if (pref_dialog && !GTK_WIDGET_VISIBLE (pref_dialog))
     {
       deck_options = bj_get_deck_options ();
-      gdk_card_deck_options_edit_set (GDK_CARD_DECK_OPTIONS_EDIT (deck_edit),
+      gtk_card_deck_options_edit_set (GTK_CARD_DECK_OPTIONS_EDIT (deck_edit),
                                       deck_options);
-      gtk_widget_show_all(pref_dialog);
+      gtk_widget_show_all (pref_dialog);
     }
+  gtk_window_present (GTK_WINDOW (pref_dialog));
 }
