@@ -1,12 +1,27 @@
+/* -*- mode:C; indent-tabs-mode:nil; tab-width:8; c-basic-offset:8; -*- */
+
 /*
  * gnect gnect.c
  *
- */
-
-
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA. 
+*/
 
 #include <stdlib.h>
 #include <time.h>
+#include <string.h>
 
 #include "config.h"
 #include "main.h"
@@ -29,17 +44,17 @@ Gnect  gnect;
 static gint source_id = 0;
 
 
-void  veleng_free(struct board *board);               /* connect4.c */
-short playgame(char *input_str, struct board *board); /* playgame.c */
-
+void  veleng_free (struct board *board);               /* connect4.c */
+short playgame (char *input_str, struct board *board); /* playgame.c */
 
 
 void
 gnect_cleanup (gint exit_code)
 {
-        DEBUG_PRINT(1, "gnect_cleanup\n");
+        DEBUG_PRINT (1, "gnect_cleanup\n");
 
-        if (anim.id) gtk_timeout_remove (anim.id);
+        if (anim.id) 
+                gtk_timeout_remove (anim.id);
 
         prefs_save ();
         gfx_free ();
@@ -47,25 +62,26 @@ gnect_cleanup (gint exit_code)
         veleng_free (gnect.veleng_board);
         prefs_free ();
 
-        DEBUG_PRINT(1, "exit(%d)\n", exit_code);
-        gtk_exit (exit_code);
+        DEBUG_PRINT (1, "exit(%d)\n", exit_code);
+        if (gtk_main_level () > 0)
+                gtk_main_quit ();
+        exit (exit_code);
 }
 
 
-
 void
 gnect_srand (guint seed)
 {
         /*
          * Seed the random number generator.
-         * If seed is 0, use system time.
          */
 
-        if (seed == 0) seed = (guint)time(NULL);
-        srand (seed);
+        if (seed != 0) {
+                g_random_set_seed (seed);
 
-        if (debugging & 4) {
-                g_printerr ("\n" APPNAME ": random number seed=%d\n\n", seed);
+                if (debugging & 4) {
+                        g_printerr ("\n" APPNAME ": random number seed=%d\n\n", seed);
+                }
         }
 }
 
@@ -78,7 +94,7 @@ gnect_get_random_num (gint n)
          * Return a random integer in the range 1..n
          */
 
-        return (rand()%n) + 1;
+        return (gint) g_random_int_range (1, n + 1);
 }
 
 
@@ -272,7 +288,7 @@ gnect_computer_move (void)
 
         /* Velena Engine */
 
-        gui_set_status (_(" Thinking..."), STATUS_MSG_SET);
+        gui_set_status (_("Thinking..."), STATUS_MSG_SET);
 
         gnect.veleng_str[0] = gnect_get_veleng_level_ch (player);
 
@@ -514,7 +530,7 @@ gnect_process_move (gint col)
 
                 /* full column, complain */
                 sound_event (SOUND_CANT_MOVE);
-                gui_set_status (_(" Sorry, full column"), STATUS_MSG_FLASH);
+                gui_set_status (_("Sorry, full column"), STATUS_MSG_FLASH);
 
         }
 
@@ -531,11 +547,11 @@ gnect_hint (void)
                 gchar level_ch = gnect.veleng_str[0];
                 gint row, col;
 
-                gui_set_status (_(" Thinking..."), STATUS_MSG_FLASH);
+                gui_set_status (_("Thinking..."), STATUS_MSG_FLASH);
 
                 gnect.veleng_str[0] = gnect_get_veleng_level_ch (PLAYER_VELENA_STRONG);
                 col = playgame (gnect.veleng_str, gnect.veleng_board);
-                hint_str = g_strdup_printf (_(" Hint: Column %d"), col);
+                hint_str = g_strdup_printf (_("Hint: Column %d"), col);
 
                 gnect.veleng_str[0] = level_ch;
 
